@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphySingle.cpp,v 1.8 2004/05/17 13:16:19 chpe Exp $
+ *  $Id: EphySingle.cpp,v 1.13 2004/07/04 23:56:26 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -27,38 +27,42 @@
 
 #include "ephy-debug.h"
 
+#include <nsEmbedString.h>
 #include <nsIURI.h>
 #include <nsIPermissionManager.h>
 #include <nsICookieManager.h>
 #include <nsIServiceManager.h>
 #include <nsICookie2.h>
+#include <nsIServiceManager.h>
 
-#ifdef ALLOW_PRIVATE_STRINGS
-#include <nsString.h>
+#ifdef ALLOW_PRIVATE_API
+#include <nsIIDNService.h>
 #endif
 
-NS_IMPL_ISUPPORTS1(EphySingle, nsIObserver)
+NS_IMPL_ISUPPORTS2(EphySingle, nsIObserver, nsISupportsWeakReference)
 
 EphySingle::EphySingle()
+: mOwner(nsnull)
 {
-	LOG ("EphySingle constructor")
-
-	mOwner = nsnull;
+	LOG ("EphySingle ctor")
 }
 
 nsresult
 EphySingle::Init (EphyEmbedSingle *aOwner)
 {
-	LOG ("EphySingle::Init")
-
-	mOwner = aOwner;
-
 	mObserverService = do_GetService ("@mozilla.org/observer-service;1");
 	NS_ENSURE_TRUE (mObserverService, NS_ERROR_FAILURE);
 
-	mObserverService->AddObserver (this, "cookie-changed", PR_FALSE);
-	mObserverService->AddObserver (this, "cookie-rejected", PR_FALSE);
-	mObserverService->AddObserver (this, "perm-changed", PR_FALSE);
+	nsresult rv;
+	rv = mObserverService->AddObserver (this, "cookie-changed", PR_TRUE);
+	rv |= mObserverService->AddObserver (this, "cookie-rejected", PR_TRUE);
+	rv |= mObserverService->AddObserver (this, "perm-changed", PR_TRUE);
+	rv |= mObserverService->AddObserver (this, "network:offline-status-changed", PR_TRUE);
+	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
+
+	mOwner = aOwner;
+
+	LOG ("EphySingle::Init")
 
 	return NS_OK;
 }
@@ -66,11 +70,14 @@ EphySingle::Init (EphyEmbedSingle *aOwner)
 nsresult
 EphySingle::Detach ()
 {
+	LOG ("EphySingle::Detach")
+
 	if (mObserverService)
 	{
 		mObserverService->RemoveObserver (this, "cookie-changed");
 		mObserverService->RemoveObserver (this, "cookie-rejected");
 		mObserverService->RemoveObserver (this, "perm-changed");
+		mObserverService->RemoveObserver (this, "network:offline-status-changed");
 	}
 
 	return NS_OK;
@@ -78,9 +85,8 @@ EphySingle::Detach ()
 
 EphySingle::~EphySingle()
 {
-	LOG ("EphySingle destructor")
+	LOG ("EphySingle dtor")
 
-	Detach();
 	mOwner = nsnull;
 }
 
@@ -128,6 +134,8 @@ NS_IMETHODIMP EphySingle::Observe(nsISupports *aSubject,
 {
 	nsresult rv = NS_OK;
 
+	LOG ("EphySingle::Observe topic %s", aTopic)
+
 	if (strcmp (aTopic, "cookie-changed") == 0)
 	{
 		/* "added" */
@@ -165,7 +173,7 @@ NS_IMETHODIMP EphySingle::Observe(nsISupports *aSubject,
 		nsCOMPtr<nsIURI> uri = do_QueryInterface (aSubject);
 		if (uri)
 		{
-			nsCAutoString spec;
+			nsEmbedCString spec;
 			uri->GetSpec (spec);
 
 			g_signal_emit_by_name (EPHY_COOKIE_MANAGER (mOwner), "cookie-rejected", spec.get());
@@ -205,24 +213,46 @@ NS_IMETHODIMP EphySingle::Observe(nsISupports *aSubject,
 			rv = NS_ERROR_FAILURE;
 		}
 	}
+	else if (strcmp (aTopic, "network:offline-status-changed") == 0)
+	{
+		/* aData is either (PRUnichar[]) "offline" or "online" */
+		gboolean offline;
+
+		offline = (aData[1] == 'f');
+
+		g_signal_emit_by_name (mOwner, "network-status", offline);
+	}
 	else
 	{
-		g_warning ("EphySingle observed unknown topic!\n");
+		g_warning ("EphySingle observed unknown topic '%s'!\n", aTopic);
 		rv = NS_ERROR_FAILURE;
 	}
 
+	LOG ("EphySingle::Observe %s", NS_SUCCEEDED (rv) ? "success" : "FAILURE")
+
 	return rv;
 }
 
 EphyCookie *
 mozilla_cookie_to_ephy_cookie (nsICookie *cookie)
 {
-	EphyCookie *info = ephy_cookie_new ();
+	EphyCookie *info;
 
-	nsCAutoString transfer;
+	nsEmbedCString transfer;
 
 	cookie->GetHost (transfer);
-	info->domain = g_strdup (transfer.get());
+
+	nsCOMPtr<nsIIDNService> idnService
+		(do_GetService ("@mozilla.org/network/idn-service;1"));
+	NS_ENSURE_TRUE (idnService, nsnull);
+
+	nsEmbedCString decoded;
+	/* ToUTF8 never fails, no need to check return value */
+	idnService->ConvertACEtoUTF8 (transfer, decoded);
+
+	info = ephy_cookie_new ();
+	info->domain = g_strdup (decoded.get());
+
 	cookie->GetName (transfer);
 	info->name = g_strdup (transfer.get());
 	cookie->GetValue (transfer);
@@ -266,26 +296,11 @@ mozilla_cookie_to_ephy_cookie (nsICookie *cookie)
 EphyPermissionInfo *
 mozilla_permission_to_ephy_permission (nsIPermission *perm)
 {
-	EphyPermissionType type = (EphyPermissionType) 0;
-
 	nsresult result;
-	nsCAutoString str;
-	result = perm->GetType(str);
+	nsEmbedCString type;
+	result = perm->GetType(type);
 	NS_ENSURE_SUCCESS (result, NULL);
 
-	if (str.Equals ("cookie"))
-	{
-		type = EPT_COOKIE;
-	}
-	else if (str.Equals ("image"))
-	{
-		type = EPT_IMAGE;
-	}
-	else if (str.Equals ("popup"))
-	{
-		type = EPT_POPUP;
-	}		
-
 	PRUint32 cap;
 	perm->GetCapability(&cap);
 	EphyPermission permission;
@@ -303,8 +318,15 @@ mozilla_permission_to_ephy_permission (nsIPermission *perm)
 			break;
 	}
 
-	nsCString host;
+	nsEmbedCString host;
 	perm->GetHost(host);
 
-	return ephy_permission_info_new (host.get(), type, permission);
+	nsCOMPtr<nsIIDNService> idnService
+		(do_GetService ("@mozilla.org/network/idn-service;1"));
+	NS_ENSURE_TRUE (idnService, nsnull);
+
+	nsEmbedCString decodedHost;
+	idnService->ConvertACEtoUTF8 (host, decodedHost);
+
+	return ephy_permission_info_new (decodedHost.get(), type.get(), permission);
 }
