@@ -38,7 +38,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: MozDownload.cpp,v 1.43 2004/07/03 22:52:28 xan Exp $
+ * $Id: MozDownload.cpp,v 1.44 2004/07/06 18:07:24 xan Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -254,7 +254,7 @@ NS_IMETHODIMP
 MozDownload::GetMIMEInfo(nsIMIMEInfo **aMIMEInfo)
 {
         NS_ENSURE_ARG_POINTER(aMIMEInfo);
-	*aMIMEInfo = mMIMEInfo;
+	NS_IF_ADDREF(*aMIMEInfo = mMIMEInfo);
 
 	return NS_OK;
 }
