@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-persist.cpp,v 1.31.4.3 2004/05/15 18:03:16 chpe Exp $
+ *  $Id: mozilla-embed-persist.cpp,v 1.39 2004/06/03 18:51:32 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -29,16 +29,17 @@
 #include "EphyBrowser.h"
 #include "EphyHeaderSniffer.h"
 #include "MozDownload.h"
+#include "EphyUtils.h"
 
 #include <stddef.h>
+
 #include <nsIWebBrowserPersist.h>
-#include <nsString.h>
 #include <nsCWebBrowserPersist.h>
-#include <nsNetUtil.h>
 #include <nsIHistoryEntry.h>
 #include <nsISHEntry.h>
-#include <nsIDocumentEncoder.h>
-#include <nsIDocument.h>
+#include <nsIDOMSerializer.h>
+#include <nsIIOService.h>
+#include <nsNetCID.h>
 
 static void
 mozilla_embed_persist_class_init (MozillaEmbedPersistClass *klass);
@@ -172,12 +173,12 @@ impl_save (EphyEmbedPersist *persist)
 	if (tmp_filename == NULL) return FALSE;
 
 	nsCOMPtr<nsILocalFile> tmpFile = do_CreateInstance (NS_LOCAL_FILE_CONTRACTID);
-	tmpFile->InitWithNativePath (nsDependentCString (tmp_filename));
+	tmpFile->InitWithNativePath (nsEmbedCString (tmp_filename));
 	g_free (tmp_filename);
 
 	/* Get the uri to save to */
 	nsCOMPtr<nsIURI> inURI;
-	nsCAutoString sURI;
+	nsEmbedCString sURI;
 	if (uri)
 	{
 		sURI.Assign (uri);
@@ -187,8 +188,9 @@ impl_save (EphyEmbedPersist *persist)
 		rv = browser->GetDocumentUrl (sURI);
 		NS_ENSURE_SUCCESS (rv, FALSE);
 	}
-      	NS_NewURI(getter_AddRefs(inURI), sURI);
-	if (!inURI) return FALSE;
+
+	rv = EphyUtils::NewURI (getter_AddRefs(inURI), sURI);
+	NS_ENSURE_SUCCESS (rv, FALSE);
 
 	/* Get post data */
 	nsCOMPtr<nsIInputStream> postData;
@@ -258,7 +260,7 @@ impl_save (EphyEmbedPersist *persist)
 	{
 		/* Filename to save to */
 		nsCOMPtr<nsILocalFile> destFile;
-		NS_NewNativeLocalFile (nsDependentCString(filename),
+		NS_NewNativeLocalFile (nsEmbedCString(filename),
 				       PR_TRUE, getter_AddRefs(destFile));
 	        NS_ENSURE_TRUE (destFile, FALSE);
 
@@ -305,22 +307,22 @@ impl_to_string (EphyEmbedPersist *persist)
 	}
 	if (NS_FAILED(rv) || !DOMDocument) return NULL;
 
-	nsCOMPtr<nsIDocument> doc = do_QueryInterface(DOMDocument);
-	if(!doc) return NULL;
+	nsCOMPtr<nsIDOMNode> node = do_QueryInterface(DOMDocument);
+	if (!node) return NULL;
 
-	nsCOMPtr<nsIDocumentEncoder> encoder = do_CreateInstance(NS_DOC_ENCODER_CONTRACTID_BASE "text/html");
-	NS_ENSURE_SUCCESS(rv, NULL);
+	nsCOMPtr<nsIDOMSerializer> serializer;
+	serializer = do_CreateInstance(NS_XMLSERIALIZER_CONTRACTID, &rv);
+	NS_ENSURE_SUCCESS (rv, FALSE);
 
-	rv = encoder->Init(doc, NS_LITERAL_STRING("text/html"), nsIDocumentEncoder::OutputAbsoluteLinks);
-	NS_ENSURE_SUCCESS(rv, NULL);
+	nsEmbedString outString;
+	serializer->SerializeToString(node, outString);
 
-	nsAutoString aOutputString;
-	encoder->EncodeToString(aOutputString);
+	nsEmbedCString cOutString;
+	NS_UTF16ToCString (outString, NS_CSTRING_ENCODING_UTF8, cOutString);
 
-	return g_strdup (NS_ConvertUCS2toUTF8(aOutputString).get());
+	return g_strdup (cOutString.get());
 }
 
-
 static GObject *
 mozilla_embed_persist_constructor (GType type, guint n_construct_properties,
 			           GObjectConstructParam *construct_params)
