@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: print-dialog.c,v 1.29 2004/06/25 13:38:36 marco Exp $
+ *  $Id: print-dialog.c,v 1.31 2004/07/17 14:34:38 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -168,11 +168,7 @@ ephy_print_get_print_info (void)
 	filename = eel_gconf_get_string (print_props[FILE_PROP].pref);
 	if (filename != NULL)
 	{
-		char *expanded;
-
-		expanded = gnome_vfs_expand_initial_tilde (filename);
-		info->file = g_filename_to_utf8 (expanded, -1, NULL, NULL, NULL);
-		g_free (expanded);
+		info->file = gnome_vfs_expand_initial_tilde (filename);
 	}
 	else
 	{
@@ -281,6 +277,7 @@ ephy_print_dialog_browse_button_cb (GtkWidget *widget,
 			  G_CALLBACK (print_filechooser_response_cb),
 			  dialog);
 
+	gtk_window_set_modal (GTK_WINDOW (fc), TRUE);
 	gtk_widget_show (GTK_WIDGET (fc));
 }
 
