@@ -41,11 +41,12 @@ typedef struct EggToolbarsModelPrivate EggToolbarsModelPrivate;
 
 typedef enum
 {
-  EGG_TB_MODEL_NOT_REMOVABLE	= 1 << 0,
-  EGG_TB_MODEL_ICONS_ONLY	= 1 << 1,
-  EGG_TB_MODEL_TEXT_ONLY	= 1 << 2,
-  EGG_TB_MODEL_ICONS_TEXT	= 1 << 3,
-  EGG_TB_MODEL_ICONS_TEXT_HORIZ	= 1 << 4,
+  EGG_TB_MODEL_NOT_REMOVABLE	 = 1 << 0,
+  EGG_TB_MODEL_ICONS_ONLY	 = 1 << 1,
+  EGG_TB_MODEL_TEXT_ONLY	 = 1 << 2,
+  EGG_TB_MODEL_ICONS_TEXT	 = 1 << 3,
+  EGG_TB_MODEL_ICONS_TEXT_HORIZ	 = 1 << 4,
+  EGG_TB_MODEL_ACCEPT_ITEMS_ONLY = 1 << 5
 } EggTbModelFlags;
 
 struct EggToolbarsModel
@@ -73,6 +74,14 @@ struct EggToolbarsModelClass
 			    int position);
   void (* toolbar_removed) (EggToolbarsModel *group,
 			    int position);
+  char * (* get_item_type) (EggToolbarsModel *model,
+			    GdkAtom           dnd_type);
+  char * (* get_item_id)   (EggToolbarsModel *model,
+			    const char       *type,
+			    const char       *data);
+  char * (* get_item_data) (EggToolbarsModel *model,
+			    const char       *type,
+			    const char       *id);
 
   /* Virtual Table */
   gboolean (* add_item)    (EggToolbarsModel *t,
@@ -80,14 +89,6 @@ struct EggToolbarsModelClass
 			    int               position,
 			    const char       *id,
 			    const char       *type);
-  char * (* get_item_type) (EggToolbarsModel *t,
-			    GdkAtom           dnd_type);
-  char * (* get_item_id)   (EggToolbarsModel *t,
-			    const char       *type,
-			    const char       *name);
-  char * (* get_item_name) (EggToolbarsModel *t,
-			    const char       *type,
-			    const char       *id);
 };
 
 GType		  egg_toolbars_model_get_type       (void);
@@ -113,7 +114,7 @@ char             *egg_toolbars_model_get_item_type  (EggToolbarsModel *t,
 char             *egg_toolbars_model_get_item_id    (EggToolbarsModel *t,
 						     const char       *type,
 			                             const char       *name);
-char             *egg_toolbars_model_get_item_name  (EggToolbarsModel *t,
+char             *egg_toolbars_model_get_item_data  (EggToolbarsModel *t,
 						     const char       *type,
 			                             const char       *id);
 gboolean	  egg_toolbars_model_add_item       (EggToolbarsModel *t,
@@ -126,12 +127,19 @@ void		  egg_toolbars_model_remove_toolbar (EggToolbarsModel *t,
 void		  egg_toolbars_model_remove_item    (EggToolbarsModel *t,
 						     int               toolbar_position,
 						     int               position);
+void		  egg_toolbars_model_move_item      (EggToolbarsModel *t,
+						     int               toolbar_position,
+						     int               position,
+						     int	       new_toolbar_position,
+						     int               new_position);
 int		  egg_toolbars_model_n_items	    (EggToolbarsModel *t,
 						     int               toolbar_position);
-const char	 *egg_toolbars_model_item_nth	    (EggToolbarsModel *t,
+void	 	  egg_toolbars_model_item_nth	    (EggToolbarsModel *t,
 						     int	       toolbar_position,
 						     int               position,
-						     gboolean         *is_separator);
+						     gboolean         *is_separator,
+						     const char      **id,
+						     const char      **type);
 int		  egg_toolbars_model_n_toolbars	    (EggToolbarsModel *t);
 const char	 *egg_toolbars_model_toolbar_nth    (EggToolbarsModel *t,
 						     int               position);
