@@ -15,9 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-debug.c,v 1.3 2004/02/21 19:59:01 chpe Exp $
+ *  $Id: ephy-debug.c,v 1.4 2004/03/17 09:02:35 marco Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "ephy-debug.h"
 
 #include <string.h>
