@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti <mpeseng@tin.it>
+ *  Copyright (C) 2003, 2004 Marco Pesenti Gritti <mpeseng@tin.it>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-bookmarks-editor.c,v 1.135 2004/05/19 10:33:19 chpe Exp $
+ * $Id: ephy-bookmarks-editor.c,v 1.139 2004/07/14 16:44:35 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -30,9 +30,17 @@
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkvbox.h>
 #include <gtk/gtkactiongroup.h>
-#include <gtk/gtktoggleaction.h>
+#include <gtk/gtkcombobox.h>
 #include <gtk/gtkuimanager.h>
 #include <gtk/gtktoggleaction.h>
+#include <gtk/gtktreeselection.h>
+#include <gtk/gtktreemodelsort.h>
+#include <gtk/gtkcelllayout.h>
+#include <gtk/gtkcellrenderertext.h>
+#include <gtk/gtkradioaction.h>
+#include <gtk/gtkclipboard.h>
+#include <gtk/gtkmain.h>
+#include <gtk/gtktreemodelsort.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
 #include <libgnomeui/gnome-stock-icons.h>
@@ -56,7 +64,7 @@
 #include "ephy-gui.h"
 #include "ephy-stock-icons.h"
 #include "ephy-search-entry.h"
-#include "ephy-toolbars-model.h"
+#include "ephy-bookmarksbar-model.h"
 #include "ephy-favicon-cache.h"
 #include "eel-gconf-extensions.h"
 #include "ephy-debug.h"
@@ -141,7 +149,7 @@ struct EphyBookmarksEditorPrivate
 	GtkUIManager *ui_merge;
 	GtkActionGroup *action_group;
 	int priority_col;
-	EphyToolbarsModel *tb_model;
+	EphyBookmarksBarModel *tb_model;
 	GHashTable *props_dialogs;
 
 	GtkTreeViewColumn *title_col;
@@ -321,6 +329,15 @@ get_target_window (EphyBookmarksEditor *editor)
 	}
 }
 
+static void
+toolbar_items_changed_cb (EggToolbarsModel *model,
+			  int toolbar_position,
+			  int position,
+			  EphyBookmarksEditor *editor)
+{
+	ephy_bookmarks_editor_update_menu (editor);
+}
+
 static void
 cmd_show_in_bookmarks_bar (GtkAction *action,
 		           EphyBookmarksEditor *editor)
@@ -328,7 +345,7 @@ cmd_show_in_bookmarks_bar (GtkAction *action,
 	EphyNode *node;
 	GList *selection;
 	gboolean state, topic;
-	gulong id;
+	guint id;
 
 	if (ephy_node_view_is_target (EPHY_NODE_VIEW (editor->priv->bm_view)))
 	{
@@ -353,13 +370,19 @@ cmd_show_in_bookmarks_bar (GtkAction *action,
 
 	if (state)
 	{
-		ephy_toolbars_model_add_bookmark
+		ephy_bookmarksbar_model_add_bookmark
 			(editor->priv->tb_model, topic, id);
 	}
 	else
 	{
-		ephy_toolbars_model_remove_bookmark
+		g_signal_handlers_block_by_func
+				(editor->priv->tb_model,
+                                 G_CALLBACK (toolbar_items_changed_cb), editor);
+		ephy_bookmarksbar_model_remove_bookmark
 			(editor->priv->tb_model, id);
+		g_signal_handlers_unblock_by_func
+				(editor->priv->tb_model,
+                                 G_CALLBACK (toolbar_items_changed_cb), editor);
 	}
 
 	g_list_free (selection);
@@ -978,10 +1001,10 @@ ephy_bookmarks_editor_update_menu (EphyBookmarksEditor *editor)
 	{
 		EphyNode *node = selected->data;
 		EphyNodePriority priority;
-		gulong id;
+		guint id;
 
 		id = ephy_node_get_id (node);
-		show_in_bookmarks_bar = ephy_toolbars_model_has_bookmark
+		show_in_bookmarks_bar = ephy_bookmarksbar_model_has_bookmark
 			(editor->priv->tb_model, id);
 
 		priority = ephy_node_get_property_int
@@ -996,12 +1019,12 @@ ephy_bookmarks_editor_update_menu (EphyBookmarksEditor *editor)
 	if (bmk_focus && selected)
 	{
 		EphyNode *node = selected->data;
-		gulong id;
+		guint id;
 
 		g_return_if_fail (node != NULL);
 
 		id = ephy_node_get_id (node);
-		show_in_bookmarks_bar = ephy_toolbars_model_has_bookmark
+		show_in_bookmarks_bar = ephy_bookmarksbar_model_has_bookmark
 			(editor->priv->tb_model, id);
 
 		g_list_free (selected);
@@ -1477,10 +1500,13 @@ ephy_bookmarks_editor_construct (EphyBookmarksEditor *editor)
 	ephy_node_view_add_column (EPHY_NODE_VIEW (key_view), _("Topics"),
 				   G_TYPE_STRING,
 				   EPHY_NODE_KEYWORD_PROP_NAME,
-				   EPHY_NODE_KEYWORD_PROP_PRIORITY,
-				   EPHY_NODE_VIEW_AUTO_SORT |
+				   EPHY_NODE_VIEW_SHOW_PRIORITY |
 				   EPHY_NODE_VIEW_EDITABLE |
 				   EPHY_NODE_VIEW_SEARCHABLE, NULL);
+	ephy_node_view_set_priority (EPHY_NODE_VIEW (key_view),
+				     EPHY_NODE_KEYWORD_PROP_PRIORITY);
+	ephy_node_view_set_sort (EPHY_NODE_VIEW (key_view), G_TYPE_STRING,
+				 EPHY_NODE_KEYWORD_PROP_NAME, GTK_SORT_ASCENDING);
 	gtk_container_add (GTK_CONTAINER (scrolled_window), key_view);
 	gtk_widget_set_size_request (key_view, 130, -1);
 	gtk_widget_show (key_view);
@@ -1537,15 +1563,16 @@ ephy_bookmarks_editor_construct (EphyBookmarksEditor *editor)
 					   col_id);
 	editor->priv->title_col = ephy_node_view_add_column
 				  (EPHY_NODE_VIEW (bm_view), _("Title"),
-				   G_TYPE_STRING, EPHY_NODE_BMK_PROP_TITLE, -1,
-				   EPHY_NODE_VIEW_AUTO_SORT |
+				   G_TYPE_STRING, EPHY_NODE_BMK_PROP_TITLE,
 				   EPHY_NODE_VIEW_EDITABLE |
 				   EPHY_NODE_VIEW_SEARCHABLE,
 				   provide_favicon);
 	editor->priv->address_col = ephy_node_view_add_column
 				  (EPHY_NODE_VIEW (bm_view), _("Address"),
 				   G_TYPE_STRING, EPHY_NODE_BMK_PROP_LOCATION,
-				   -1, 0, NULL);
+				   0, NULL);
+	ephy_node_view_set_sort (EPHY_NODE_VIEW (bm_view), G_TYPE_STRING,
+				 EPHY_NODE_BMK_PROP_TITLE, GTK_SORT_ASCENDING);
 	gtk_container_add (GTK_CONTAINER (scrolled_window), bm_view);
 	gtk_widget_show (bm_view);
 	editor->priv->bm_view = bm_view;
@@ -1652,15 +1679,6 @@ ephy_bookmarks_editor_get_property (GObject *object,
 	}
 }
 
-static void
-toolbar_items_changed_cb (EphyToolbarsModel *model,
-			  int toolbar_position,
-			  int position,
-			  EphyBookmarksEditor *editor)
-{
-	ephy_bookmarks_editor_update_menu (editor);
-}
-
 static void
 ephy_bookmarks_editor_init (EphyBookmarksEditor *editor)
 {
@@ -1668,8 +1686,9 @@ ephy_bookmarks_editor_init (EphyBookmarksEditor *editor)
 
 	editor->priv->props_dialogs = g_hash_table_new (g_direct_hash,
                                                         g_direct_equal);
-	editor->priv->tb_model = EPHY_TOOLBARS_MODEL
-		(ephy_shell_get_toolbars_model (ephy_shell, FALSE));
+	editor->priv->tb_model = EPHY_BOOKMARKSBAR_MODEL
+		(ephy_bookmarks_get_toolbars_model
+			(ephy_shell_get_bookmarks (ephy_shell)));
 
 	g_signal_connect (editor->priv->tb_model, "item_added",
 			  G_CALLBACK (toolbar_items_changed_cb), editor);
