@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-new-bookmark.c,v 1.37 2004/03/17 09:08:08 marco Exp $
+ *  $Id: ephy-new-bookmark.c,v 1.42 2004/06/24 10:03:31 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -28,6 +28,7 @@
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkvbox.h>
 #include <gtk/gtkstock.h>
+#include <gtk/gtkimage.h>
 #include <gtk/gtkscrolledwindow.h>
 #include <gtk/gtkeditable.h>
 #include <glib/gi18n.h>
@@ -54,12 +55,17 @@ static void ephy_new_bookmark_get_property (GObject *object,
 
 #define EPHY_NEW_BOOKMARK_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_NEW_BOOKMARK, EphyNewBookmarkPrivate))
 
+enum
+{
+	RESPONSE_NEW_TOPIC
+};
+
 struct EphyNewBookmarkPrivate
 {
 	EphyBookmarks *bookmarks;
 	char *location;
 	char *icon;
-	gulong id;
+	guint id;
 
 	GtkWidget *title_entry;
 	GtkWidget *topics_selector;
@@ -176,6 +182,10 @@ response_cb (EphyNewBookmark *new_bookmark,
 	     int response_id,
 	     gpointer user_data)
 {
+	EphyTopicsSelector *selector;
+
+	selector = EPHY_TOPICS_SELECTOR (new_bookmark->priv->topics_selector);
+
 	switch (response_id)
 	{
 		case GTK_RESPONSE_HELP:
@@ -183,6 +193,9 @@ response_cb (EphyNewBookmark *new_bookmark,
 		       		       "epiphany",
 		       		       "to-create-new-bookmark");
 			break;
+		case RESPONSE_NEW_TOPIC:
+			ephy_topics_selector_new_topic (selector);
+			break;
 		/* For both OK and Cancel we want to destroy the dialog */
 		case GTK_RESPONSE_OK:
 			ephy_new_bookmark_add (new_bookmark);
@@ -282,6 +295,9 @@ ephy_new_bookmark_construct (EphyNewBookmark *editor)
 	gtk_dialog_add_button (GTK_DIALOG (editor),
 			       GTK_STOCK_HELP,
 			       GTK_RESPONSE_HELP);
+	gtk_dialog_add_button (GTK_DIALOG (editor),
+			       _("_New Topic"),
+			       RESPONSE_NEW_TOPIC);
 	gtk_dialog_add_button (GTK_DIALOG (editor),
 			       GTK_STOCK_CANCEL,
 			       GTK_RESPONSE_CANCEL);
@@ -333,7 +349,7 @@ duplicate_dialog_construct (GtkWindow *parent,
 	label = gtk_label_new (NULL);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	tmp_title = g_strconcat ("<b>", title, "</b>", NULL);
+	tmp_title = g_markup_printf_escaped ("<b>%s</b>", title);
 	tmp_str = g_strdup_printf (_("A bookmark titled %s already exists for this page."),
 			           tmp_title);
 	str = g_strconcat ("<big>", tmp_str, "</big>", NULL);
@@ -492,7 +508,7 @@ ephy_new_bookmark_set_icon (EphyNewBookmark *bookmark,
 	bookmark->priv->icon = icon ? g_strdup (icon) : NULL;
 }
 
-gulong
+guint
 ephy_new_bookmark_get_id (EphyNewBookmark *bookmark)
 {
 	return bookmark->priv->id;
