@@ -15,13 +15,15 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: window-commands.c,v 1.123 2004/05/29 18:53:25 chpe Exp $
+ *  $Id: window-commands.c,v 1.129 2004/07/19 08:27:06 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
+#include "ephy-embed-shell.h"
+#include "ephy-embed-single.h"
 #include "ephy-shell.h"
 #include "ephy-embed-factory.h"
 #include "ephy-embed-persist.h"
@@ -42,7 +44,7 @@
 #include "ephy-state.h"
 #include "ephy-gui.h"
 #include "ephy-zoom.h"
-#include "ephy-toolbars-model.h"
+#include "egg-toolbars-model.h"
 #include "egg-editable-toolbar.h"
 #include "egg-toolbar-editor.h"
 
@@ -53,6 +55,8 @@
 #include <libgnomeui/gnome-stock-icons.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include <gtk/gtkeditable.h>
+#include <gtk/gtkmain.h>
+#include <gtk/gtkicontheme.h>
 #include <gtk/gtktoggleaction.h>
 #include <libgnomeui/gnome-about.h>
 #include <glib/gi18n.h>
@@ -86,18 +90,11 @@ window_cmd_file_print_preview (GtkAction *action,
 			       EphyWindow *window)
 {
 	EphyEmbed *embed;
-	EmbedPrintInfo *info;
 
 	embed = ephy_window_get_active_embed (window);
 	g_return_if_fail (EPHY_IS_EMBED (embed));
 
-	info = ephy_print_get_print_info ();
-	info->preview = TRUE;
-
-	ephy_embed_print (embed, info);
-
-	ephy_print_info_free (info);
-
+	ephy_embed_set_print_preview_mode (embed, TRUE);
 	ephy_window_set_print_preview (window, TRUE);
 }
 
@@ -105,7 +102,12 @@ void
 window_cmd_file_print (GtkAction *action,
 		       EphyWindow *window)
 {
-	ephy_window_print (window);
+	EphyEmbed *embed;
+
+	embed = ephy_window_get_active_embed (window);
+	g_return_if_fail (EPHY_IS_EMBED (embed));
+
+	ephy_embed_print (embed);
 }
 
 void
@@ -272,8 +274,7 @@ window_cmd_view_reload (GtkAction *action,
 
 	ephy_embed_activate (embed);
 
-	ephy_embed_reload (embed, force ? EMBED_RELOAD_FORCE
-					: EMBED_RELOAD_NORMAL);
+	ephy_embed_reload (embed, force);
 }
 
 void
@@ -285,7 +286,7 @@ window_cmd_file_new_window (GtkAction *action,
 	tab = ephy_window_get_active_tab (window);
 	g_return_if_fail (tab != NULL);
 
-	ephy_shell_new_tab (ephy_shell, NULL, tab, NULL,
+	ephy_shell_new_tab (ephy_shell, window, tab, NULL,
 			    EPHY_NEW_TAB_NEW_PAGE |
 			    EPHY_NEW_TAB_IN_NEW_WINDOW);
 }
@@ -431,12 +432,31 @@ window_cmd_file_save_as (GtkAction *action,
 	g_object_unref (G_OBJECT(persist));
 }
 
+
+void
+window_cmd_file_work_offline (GtkAction *action,
+		              EphyWindow *window)
+{
+	EphyEmbedSingle *single;
+	gboolean offline;
+
+	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (embed_shell));
+	offline = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
+	ephy_embed_single_set_offline_mode (single, offline);
+}
+
 void
 window_cmd_file_close_window (GtkAction *action,
 		              EphyWindow *window)
 {
 	EphyTab *tab;
 
+	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_QUIT) &&
+	    gtk_notebook_get_n_pages (GTK_NOTEBOOK (ephy_window_get_notebook (window))) == 1)
+	{
+		return;
+	}
+
 	tab = ephy_window_get_active_tab (window);
 	g_return_if_fail (tab != NULL);
 
@@ -592,6 +612,9 @@ void
 window_cmd_view_fullscreen (GtkAction *action,
 			    EphyWindow *window)
 {
+	/* Otherwise the other toolbar layout shows briefly while switching */
+	gtk_widget_hide (ephy_window_get_toolbar (window));
+
 	if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)))
 	{
 		gtk_window_fullscreen (GTK_WINDOW (window));
@@ -806,30 +829,26 @@ window_cmd_edit_prefs (GtkAction *action,
 
 static void
 toolbar_editor_destroy_cb (GtkWidget *tbe,
-			   Toolbar *t)
+			   EphyWindow *window)
 {
-	egg_editable_toolbar_set_edit_mode (EGG_EDITABLE_TOOLBAR (t), FALSE);
+	egg_editable_toolbar_set_edit_mode (EGG_EDITABLE_TOOLBAR
+		(ephy_window_get_toolbar (window)), FALSE);
+	egg_editable_toolbar_set_edit_mode (EGG_EDITABLE_TOOLBAR
+		(ephy_window_get_bookmarksbar (window)), FALSE);
 }
 
 static void
 toolbar_editor_response_cb (GtkDialog  *dialog,
 			    gint response_id,
-			    gpointer data)
+			    EggToolbarsModel *model)
 {
-	EphyToolbarsModel *model;
-	int n;
-
 	switch (response_id)
 	{
 	case GTK_RESPONSE_CLOSE:
 		gtk_widget_destroy (GTK_WIDGET (dialog));
 		break;
 	case RESPONSE_ADD_TOOLBAR:
-		model = EPHY_TOOLBARS_MODEL
-			(ephy_shell_get_toolbars_model (ephy_shell, FALSE));
-		n = egg_toolbars_model_n_toolbars (EGG_TOOLBARS_MODEL (model));
-		egg_toolbars_model_add_toolbar (EGG_TOOLBARS_MODEL (model),
-						n - 1, "UserCreated");
+		egg_toolbars_model_add_toolbar (model, -1, "UserCreated");
 		break;
 	case GTK_RESPONSE_HELP:
 		ephy_gui_help (GTK_WINDOW (dialog), "epiphany", "to-edit-toolbars");
@@ -842,31 +861,28 @@ window_cmd_edit_toolbar (GtkAction *action,
 			 EphyWindow *window)
 {
 	GtkWidget *editor;
-	EphyToolbarsModel *model;
+	EggToolbarsModel *model;
 	GtkWidget *t;
 	GtkWidget *dialog;
 
-	model = EPHY_TOOLBARS_MODEL
+	model = EGG_TOOLBARS_MODEL
 		(ephy_shell_get_toolbars_model (ephy_shell, FALSE));
 	t = ephy_window_get_toolbar (window);
 
 	dialog = gtk_dialog_new ();
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Toolbar Editor"));
-        gtk_window_set_transient_for (GTK_WINDOW (dialog),
-				      GTK_WINDOW (window));
+        gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (window));
+	gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
 
-	editor = egg_toolbar_editor_new
-		(GTK_UI_MANAGER (window->ui_merge),
-		 EGG_TOOLBARS_MODEL (model));
+	editor = egg_toolbar_editor_new (GTK_UI_MANAGER (window->ui_merge), model);
 	egg_toolbar_editor_load_actions (EGG_TOOLBAR_EDITOR (editor),
 					 ephy_file ("epiphany-toolbar.xml"));
 	gtk_container_set_border_width (GTK_CONTAINER (EGG_TOOLBAR_EDITOR (editor)), 5);
 	gtk_box_set_spacing (GTK_BOX (EGG_TOOLBAR_EDITOR (editor)), 5);
 	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), editor);
 	g_signal_connect (editor, "destroy",
-			  G_CALLBACK (toolbar_editor_destroy_cb),
-			  t);
+			  G_CALLBACK (toolbar_editor_destroy_cb), window);
 	gtk_widget_show (editor);
 	
 	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
@@ -881,7 +897,7 @@ window_cmd_edit_toolbar (GtkAction *action,
 			       GTK_STOCK_HELP, GTK_RESPONSE_HELP);
 	
 	g_signal_connect (G_OBJECT (dialog), "response",
-			  G_CALLBACK (toolbar_editor_response_cb), NULL);
+			  G_CALLBACK (toolbar_editor_response_cb), model);
 	ephy_state_add_window (dialog,
 			       "toolbar_editor",
 		               500, 330,
@@ -889,6 +905,8 @@ window_cmd_edit_toolbar (GtkAction *action,
 	gtk_widget_show (dialog);
 
 	egg_editable_toolbar_set_edit_mode (EGG_EDITABLE_TOOLBAR (t), TRUE);
+	egg_editable_toolbar_set_edit_mode
+		(EGG_EDITABLE_TOOLBAR (ephy_window_get_bookmarksbar (window)), TRUE);
 }
 
 void
